# Torrent client
Using libtorrent (arvidn) with python bindings (example: python3-libtorrent).\
libgtk-4.so required.
###### Donations
| Name      | Address                                    |
|-----------|--------------------------------------------|
| Bitcoin   | 1DcXWYXpmopfgg3oZYWVBTLbDTmQ6nWG7s         |
| Ethereum  | 0xd8ea69f877b93fa663652bc2d944e71a338cd5f9 |
| Dogecoin  | DP28QjzNcWCF4XqdUoDcZ7DeWKhjTmZqY9         |
| Decred    | DsSdAMyVkKbX18fXK5pYJbNgXhfisc4onT9        |
| Digibyte  | DPK6t296EMSHNMzuoMyP2zbxRjtisaaCRu         |
| Ravencoin | RECqJbqzqNiGQeodcRSBqkAZjh2fbroUHL         |